Method: Mapper::Base#map

Defined in:
lib/bns/mapper/base.rb

#map(_response) ⇒ Object

An method meant to prepare or organize the data coming from an implementation of the Fetcher::Base interface. Must be overridden by subclasses, with specific logic based on the use case.


Params: * Fetcher::Notion::Types::Response response: Response produced by a fetcher.

raises Domain::Exceptions::FunctionNotImplemented when missing implementation.

returns ListDomain:: Mapped list of data, ready to be formatted.



26
27
28
# File 'lib/bns/mapper/base.rb', line 26

def map(_response)
  raise Domain::Exceptions::FunctionNotImplemented
end